@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2014-2021 Canonical Ltd.
- * Copyright (C) 2021-2023 Colin Ian King.
+ * Copyright (C) 2021-2024 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -674,7 +674,7 @@ static int pid_max_digits(void)
 
 	buf[n] = '\0';
 	max_digits = 0;
-	while (buf[max_digits] >= '0' && buf[max_digits] <= '9')
+	while ((max_digits < n) && (buf[max_digits] >= '0') && (buf[max_digits] <= '9'))
 		max_digits++;
 	if (max_digits < min_digits)
 		max_digits = min_digits;
